==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/NativeUI.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { UIElementPropertyAccessorFactory } from "./UIElementPropertyAccessorFactory";
import { MatrixTransform } from "./MatrixTransform";
import { TransformMatrixHelpler } from "./TransformMatrixHelpler";
/**
 * @hidden
 */
var NativeUI = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUI, _super);
    function NativeUI() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUI.ae = function (a, b, c) {
        var d = UIElementPropertyAccessorFactory.c.a(a, 0);
        d.c(b, c);
    };
    NativeUI.k = function (a, b) {
        var c = UIElementPropertyAccessorFactory.c.a(a, 0);
        return c.b(b);
    };
    NativeUI.w = function (a, b) {
        NativeUI.ae(1, a, b);
    };
    NativeUI.f = function (a) {
        return NativeUI.k(1, a);
    };
    NativeUI.l = function (a, b) {
        NativeUI.ae(2, a, b);
    };
    NativeUI.ah = function (a) {
        return NativeUI.k(2, a);
    };
    NativeUI.m = function (a, b) {
        NativeUI.ae(3, a, b);
    };
    NativeUI.ai = function (a) {
        return NativeUI.k(3, a);
    };
    NativeUI.o = function (a, b) {
        NativeUI.ae(4, a, b);
    };
    NativeUI.am = function (a) {
        return NativeUI.k(4, a);
    };
    NativeUI.n = function (a, b) {
        NativeUI.ae(5, a, b);
    };
    NativeUI.x = function (a, b) {
        NativeUI.ae(6, a, b);
    };
    NativeUI.ao = function (a) {
        return NativeUI.k(6, a);
    };
    NativeUI.ag = function (a) {
        return NativeUI.k(5, a);
    };
    NativeUI.p = function (a, b) {
        NativeUI.ae(7, a, b);
    };
    NativeUI.aj = function (a) {
        return NativeUI.k(7, a);
    };
    NativeUI.r = function (a, b) {
        NativeUI.ae(8, a, b);
    };
    NativeUI.c = function (a) {
        return NativeUI.k(8, a);
    };
    NativeUI.af = function (a, b) {
        NativeUI.ae(9, a, b);
    };
    NativeUI.j = function (a) {
        return NativeUI.k(9, a);
    };
    NativeUI.s = function (a, b) {
        NativeUI.ae(10, a, b);
    };
    NativeUI.d = function (a) {
        return NativeUI.k(10, a);
    };
    NativeUI.u = function (a, b) {
        NativeUI.ae(11, a, b);
    };
    NativeUI.ac = function (a, b) {
        NativeUI.ae(12, a, b);
    };
    NativeUI.e = function (a) {
        return NativeUI.k(11, a);
    };
    NativeUI.i = function (a) {
        return NativeUI.k(12, a);
    };
    NativeUI.v = function (a, b) {
        NativeUI.ae(13, a, b);
    };
    NativeUI.an = function (a) {
        return NativeUI.k(13, a);
    };
    NativeUI.ad = function (a, b) {
        var c = TransformMatrixHelpler.f(b);
        var d = new MatrixTransform();
        d.j = c;
        NativeUI.ae(14, a, d);
    };
    NativeUI.al = function (a) {
        return NativeUI.k(14, a);
    };
    NativeUI.y = function (a, b) {
        NativeUI.ae(15, a, b);
    };
    NativeUI.q = function (a, b) {
        NativeUI.ae(16, a, b);
    };
    NativeUI.ak = function (a) {
        return NativeUI.k(15, a);
    };
    NativeUI.ab = function (a, b) {
        NativeUI.ae(17, a, b);
    };
    NativeUI.h = function (a) {
        return NativeUI.k(17, a);
    };
    NativeUI.z = function (a, b) {
        NativeUI.ae(18, a, b);
    };
    NativeUI.a = function (a) {
        return NativeUI.k(18, a);
    };
    NativeUI.aa = function (a, b) {
        NativeUI.ae(19, a, b);
    };
    NativeUI.g = function (a) {
        return NativeUI.k(19, a);
    };
    NativeUI.t = function (a, b) {
        NativeUI.ae(21, a, b);
    };
    NativeUI.b = function (a) {
        return NativeUI.k(21, a);
    };
    NativeUI.$t = markType(NativeUI, 'NativeUI');
    return NativeUI;
}(Base));
export { NativeUI };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/NativeUI.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { UIElementPropertyAccessorFactory } from "./UIElementPropertyAccessorFactory";
import { MatrixTransform } from "./MatrixTransform";
import { TransformMatrixHelpler } from "./TransformMatrixHelpler";
/**
 * @hidden
 */
var NativeUI = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUI, _super);
    function NativeUI() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUI.ag = function (a, b, c) {
        var d = UIElementPropertyAccessorFactory.c.a(a, 0);
        d.c(b, c);
    };
    NativeUI.l = function (a, b) {
        var c = UIElementPropertyAccessorFactory.c.a(a, 0);
        return c.b(b);
    };
    NativeUI.y = function (a, b) {
        NativeUI.ag(1, a, b);
    };
    NativeUI.g = function (a) {
        return NativeUI.l(1, a);
    };
    NativeUI.m = function (a, b) {
        NativeUI.ag(2, a, b);
    };
    NativeUI.aj = function (a) {
        return NativeUI.l(2, a);
    };
    NativeUI.n = function (a, b) {
        NativeUI.ag(3, a, b);
    };
    NativeUI.ak = function (a) {
        return NativeUI.l(3, a);
    };
    NativeUI.p = function (a, b) {
        NativeUI.ag(4, a, b);
    };
    NativeUI.ap = function (a) {
        return NativeUI.l(4, a);
    };
    NativeUI.o = function (a, b) {
        NativeUI.ag(5, a, b);
    };
    NativeUI.z = function (a, b) {
        NativeUI.ag(6, a, b);
    };
    NativeUI.ar = function (a) {
        return NativeUI.l(6, a);
    };
    NativeUI.ai = function (a) {
        return NativeUI.l(5, a);
    };
    NativeUI.q = function (a, b) {
        NativeUI.ag(7, a, b);
    };
    NativeUI.al = function (a) {
        return NativeUI.l(7, a);
    };
    NativeUI.s = function (a, b) {
        NativeUI.ag(8, a, b);
    };
    NativeUI.c = function (a) {
        return NativeUI.l(8, a);
    };
    NativeUI.ah = function (a, b) {
        NativeUI.ag(9, a, b);
    };
    NativeUI.k = function (a) {
        return NativeUI.l(9, a);
    };
    NativeUI.x = function (a, b) {
        NativeUI.ag(26, a, b);
    };
    NativeUI.f = function (a) {
        return NativeUI.l(26, a);
    };
    NativeUI.t = function (a, b) {
        NativeUI.ag(10, a, b);
    };
    NativeUI.d = function (a) {
        return NativeUI.l(10, a);
    };
    NativeUI.v = function (a, b) {
        NativeUI.ag(11, a, b);
    };
    NativeUI.ae = function (a, b) {
        NativeUI.ag(12, a, b);
    };
    NativeUI.e = function (a) {
        return NativeUI.l(11, a);
    };
    NativeUI.j = function (a) {
        return NativeUI.l(12, a);
    };
    NativeUI.w = function (a, b) {
        NativeUI.ag(13, a, b);
    };
    NativeUI.aq = function (a) {
        return NativeUI.l(13, a);
    };
    NativeUI.af = function (a, b) {
        var c = TransformMatrixHelpler.f(b);
        var d = new MatrixTransform();
        d.j = c;
        NativeUI.ag(14, a, d);
    };
    NativeUI.ao = function (a) {
        return NativeUI.l(14, a);
    };
    NativeUI.aa = function (a, b) {
        NativeUI.ag(15, a, b);
    };
    NativeUI.r = function (a, b) {
        NativeUI.ag(16, a, b);
    };
    NativeUI.am = function (a) {
        return NativeUI.l(16, a);
    };
    NativeUI.an = function (a) {
        return NativeUI.l(15, a);
    };
    NativeUI.ad = function (a, b) {
        NativeUI.ag(17, a, b);
    };
    NativeUI.i = function (a) {
        return NativeUI.l(17, a);
    };
    NativeUI.ab = function (a, b) {
        NativeUI.ag(18, a, b);
    };
    NativeUI.a = function (a) {
        return NativeUI.l(18, a);
    };
    NativeUI.ac = function (a, b) {
        NativeUI.ag(19, a, b);
    };
    NativeUI.h = function (a) {
        return NativeUI.l(19, a);
    };
    NativeUI.u = function (a, b) {
        NativeUI.ag(21, a, b);
    };
    NativeUI.b = function (a) {
        return NativeUI.l(21, a);
    };
    NativeUI.$t = markType(NativeUI, 'NativeUI');
    return NativeUI;
}(Base));
export { NativeUI };
